@@ -110,11 +110,10 @@ class AbstractEvaluator(ABC):
 
     def validate_error_mode(self) -> None:
         if self.error_mode not in self.error_mode_options:
-            msg = (
+            raise ValueError(
                 f"Invalid error mode '{self.error_mode}', "
                 f"only {self.error_mode_options} are allowed"
             )
-            raise ValueError(msg)
         if self.error_mode == "Failfast":
             if self.error_value is None:
                 return
@@ -684,6 +683,10 @@ class EvaluatorEP(AbstractEvaluator, ABC):
             )
             assert version == eplus.get_idf_version(building), "Incorrect version"
 
+        if not (str(epw).endswith(".epw") and os.path.exists(epw)):
+            raise ValueError(
+                f"epw argument expects path to an epw file, file provided was: {epw}"
+            )
         self.epw = epw
 
         # epw can be read when needed, instead of here
@@ -857,13 +860,11 @@ class EvaluatorEH(AbstractEvaluator, ABC):
             error_value=error_value,
             progress_bar=progress_bar,
         )
-        # TODO: Either fully port the evaluator over to the config.py or switch everything over to config.yaml
         self.out_dir = out_dir
         self.err_dir = err_dir
         self.hub = hub
         self.problem = problem
-        with open(Path(config.baseDir, "config.yaml"), "r") as file:
-            self.config_settings = yaml.safe_load(file)
+        self.config_settings = config.solver_settings
 
     # override of validate due to pyehub model inputs being lists
     def validate(self, values: Sequence) -> None:
